import { Aggregate, AggregateEncryptionFactory, AggregateProjection, Command, CommandResult, Event, SecretsManager } from 'resolve-core';
declare type EventPublisher = {
    publish: ({ event }: {
        event: Event;
    }) => Promise<void>;
};
declare type EventstoreAdapter = {
    getNextCursor: Function;
    saveSnapshot: Function;
    getSecretsManager: () => Promise<SecretsManager>;
    loadSnapshot: (snapshotKey: string) => Promise<string | null>;
    loadEvents: (param: {
        aggregateIds: string[];
        cursor: null;
        limit: number;
    }) => Promise<{
        events: any[];
    }>;
};
declare type AggregateMeta = {
    name: string;
    commands: Aggregate;
    projection: AggregateProjection;
    serializeState: Function;
    deserializeState: Function;
    encryption: AggregateEncryptionFactory | null;
    invariantHash?: string;
};
export declare type CommandExecutor = {
    (command: Command): Promise<CommandResult>;
    dispose: () => Promise<void>;
};
export declare type CommandExecutorBuilder = (context: {
    publisher: EventPublisher;
    aggregates: AggregateMeta[];
    performanceTracer?: any;
    eventstoreAdapter: EventstoreAdapter;
}) => CommandExecutor;
declare const CommandError: Function;
export { CommandError };
declare const createCommand: CommandExecutorBuilder;
export default createCommand;
